@@ -6,6 +6,7 @@ available. (Giving the user a chance to immediately install zstandard.)
 import importlib
 import subprocess
 import sys
+import warnings
 
 
 def test_degraded():
@@ -17,21 +18,28 @@ def test_degraded():
         # this is only testing conda_package_handling's code, and does not test
         # that conda_package_streaming works without zstandard.
 
-        import conda_package_handling.api
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")  # Ensure warnings are sent
+            import conda_package_handling.api
 
-        importlib.reload(conda_package_handling.api)
+            importlib.reload(conda_package_handling.api)
 
-        assert conda_package_handling.api.libarchive_enabled is False
+            assert len(w) == 1
+            assert issubclass(w[-1].category, UserWarning)
+            assert "zstandard" in str(w[-1].message)
+            assert conda_package_handling.api.libarchive_enabled is False
 
     finally:
         sys.modules.pop("zstandard", None)
         sys.modules.pop("conda_package_handling.conda_fmt", None)
         sys.modules.pop("conda_package_streaming.transmute", None)
-        import conda_package_handling.api
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")  # Ensure warnings are sent
+            import conda_package_handling.api
 
-        importlib.reload(conda_package_handling.api)
-
-        assert conda_package_handling.api.libarchive_enabled is True
+            importlib.reload(conda_package_handling.api)
+            assert len(w) == 0
+            assert conda_package_handling.api.libarchive_enabled is True
 
 
 def test_degraded_subprocess():
