@@ -28,10 +28,9 @@ def test_rename_to_trash(testing_workdir, mocker, errno):
 
     # force a second error for the inner rename try (after unlink fails)
     if sys.platform == "win32":
-
         with open("dummy", "w") as f:
             f.write("weeee")
-        rename = mocker.patch("os.rename")
+        mocker.patch("os.rename")
         unlink.side_effect = EnvironmentError(errno, "")
         utils.unlink_or_rename_to_trash("dummy")
         assert os.path.isfile("dummy.conda_trash")
@@ -42,7 +41,7 @@ def test_delete_trash(testing_workdir, mocker):
     isdir.return_value = True
     lexists = mocker.patch("conda_package_handling.utils.lexists")
     lexists.return_value = False
-    rmdir = mocker.patch("conda_package_handling.utils.rmdir")
+    mocker.patch("conda_package_handling.utils.rmdir")
 
     os.makedirs("folder")
     with open("folder/dummy.conda_trash", "w") as f:
